import { NextResponse } from "next/server";
import dbConnect from "@/lib/mongodb";
import User from "@/models/User";
import bcrypt from "bcryptjs";

export async function POST(request) {
  try {
    await dbConnect();
    const { username, password } = await request.json();

    // 检查用户名是否已存在
    const existingUser = await User.findOne({ username });
    if (existingUser) {
      return NextResponse.json({ error: "用户名已存在" }, { status: 400 });
    }

    // 加密密码
    const hashedPassword = await bcrypt.hash(password, 10);

    // 生成6位数的userId
    const userId = Math.floor(100000 + Math.random() * 900000);

    // 创建新用户
    const user = await User.create({
      username,
      password: hashedPassword,
      userId,
    });

    return NextResponse.json({
      message: "注册成功",
      user: {
        id: user._id,
        userId: user.userId,
        username: user.username,
        createdAt: user.createdAt,
      },
    });
  } catch (error) {
    console.error("注册失败:", error);
    return NextResponse.json({ error: "注册失败" }, { status: 500 });
  }
}
